/*
** Module   : ParmType
** Abstract : Parameter types enumerator.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130304 Created initial version.
*/

package com.goldencode.p2j.convert;

/**                   
 * Encodes the possible parameter types in Progress. This includes a code for each
 * individual wrapper type.  But it also includes codes for the common parent types
 * for use in cases where the parameter can be one of multiple related types (e.g.
 * NUMBERTYPE</action> would indicate that an <code>INTEGER</code>,
 * <code>INT64</code> or <code>DECIMAL</code> could all be used as a parameter).
 */ 
public enum ParmType
{
   CHAR { @Override public String toString() { return "character"; } },
   LC { @Override public String toString() { return "longchar"; } },
   CLOB { @Override public String toString() { return "CLOB"; } },
   LARGE_CHAR_OBJECT { @Override public String toString() { return "LARGE_CHAR_OBJECT"; } },
   TEXT { @Override public String toString() { return "Text"; } },
   INT { @Override public String toString() { return "integer"; } },
   DEC { @Override public String toString() { return "decimal"; } },
   INT64 { @Override public String toString() { return "int64"; } },
   NUM { @Override public String toString() { return "NumberType"; } },
   NUM_VARARGS { @Override public String toString() { return "NumberType[]"; } },
   LOG { @Override public String toString() { return "logical"; } },
   DATE { @Override public String toString() { return "date"; } },
   DT { @Override public String toString() { return "datetime"; } },
   DTTZ { @Override public String toString() { return "datetimetz"; } },
   HANDLE { @Override public String toString() { return "handle"; } },
   WID { @Override public String toString() { return "GenericWidget"; } },
   RECID { @Override public String toString() { return "recid"; } },
   RECORD { @Override public String toString() { return "record"; } },
   ROWID { @Override public String toString() { return "rowid"; } },
   ROWID_ARRAY { @Override public String toString() { return "rowid[]"; } },
   MEM { @Override public String toString() { return "memptr"; } },
   RAW { @Override public String toString() { return "raw"; } },
   BIN { @Override public String toString() { return "BinaryType"; } },
   BDT { @Override public String toString() { return "BaseDataType"; } },
   BDT_ARRAY { @Override public String toString() { return "BaseDataType[]"; } },
   BDT_VARARGS { @Override public String toString() { return "BaseDataType[]"; } }
}

